@@ -59,12 +59,12 @@ cd "$(dirname "$REAL_PATH")/../docker/"
 REPO_VERSION_CLEAN=$(echo "$REPO_VERSION" | sed 's|/|-|g')
 
 [ -z "$APP_REPO" ] && APP_REPO=$(\grep APP_REPO Dockerfile | cut -f2 -d"=")
-GITHUB_REPO=$(echo "$APP_REPO" | sed 's/git.openstack.org/github.com/' | \
+GITHUB_REPO=$(echo "$APP_REPO" | sed 's/review.opendev.org/github.com/' | \
               sed 's/ssh:/https:/')
 
 if [ -z "$CONSTRAINTS_FILE" ]; then
     CONSTRAINTS_FILE=$(\grep CONSTRAINTS_FILE Dockerfile | cut -f2 -d"=") || true
-    : "${CONSTRAINTS_FILE:=http://git.openstack.org/cgit/openstack/requirements/plain/upper-constraints.txt}"
+    : "${CONSTRAINTS_FILE:=https://opendev.org/openstack/requirements/raw/branch/master/upper-constraints.txt}"
 fi
 
 : "${CONSTRAINTS_BRANCH:=$2}"
@@ -75,10 +75,11 @@ fi
 case "$REPO_VERSION" in
     *stable*)
         CONSTRAINTS_BRANCH_CLEAN="$REPO_VERSION"
+        CONSTRAINTS_FILE=${CONSTRAINTS_FILE/master/$CONSTRAINTS_BRANCH_CLEAN}
         # Get monasca-common version from stable upper constraints file.
         CONSTRAINTS_TMP_FILE=$(mktemp)
         wget --output-document "$CONSTRAINTS_TMP_FILE" \
-            "$CONSTRAINTS_FILE"?h="$CONSTRAINTS_BRANCH_CLEAN"
+            $CONSTRAINTS_FILE
         UPPER_COMMON=$(\grep 'monasca-common' "$CONSTRAINTS_TMP_FILE")
         # Get only version part from monasca-common.
         UPPER_COMMON_VERSION="${UPPER_COMMON##*===}"
@@ -92,7 +93,7 @@ esac
 # Monasca-common variables.
 if [ -z "$COMMON_REPO" ]; then
     COMMON_REPO=$(\grep COMMON_REPO Dockerfile | cut -f2 -d"=") || true
-    : "${COMMON_REPO:=https://git.openstack.org/openstack/monasca-common}"
+    : "${COMMON_REPO:=https://review.opendev.org/openstack/monasca-common}"
 fi
 : "${COMMON_VERSION:=$3}"
 if [ -z "$COMMON_VERSION" ]; then
@@ -143,7 +144,6 @@ docker build --no-cache \
     --build-arg REPO_VERSION="$REPO_VERSION" \
     --build-arg GIT_COMMIT="$GIT_COMMIT" \
     --build-arg CONSTRAINTS_FILE="$CONSTRAINTS_FILE" \
-    --build-arg CONSTRAINTS_BRANCH="$CONSTRAINTS_BRANCH_CLEAN" \
     --build-arg COMMON_REPO="$COMMON_REPO" \
     --build-arg COMMON_VERSION="$COMMON_VERSION" \
     --build-arg COMMON_GIT_COMMIT="$COMMON_GIT_COMMIT" \
